@@ -32,11 +32,11 @@
 ####
 ################################################################
 ################################################################
-.priorInvgamma <- function(a,b,xmax){
+.priorInvgamma <- function(a,b,xmax,...){
   x = seq(0,100,len=1000)
   tau = 1/x
   y = dgamma(tau,shape=a,rate=b)*x^(-2)
-  plot(x,y,xlab=expression(sigma^2),ylab=expression(pi(sigma^2)),type="l",xlim=c(0,xmax))
+  plot(x,y,xlab=expression(sigma^2),ylab=expression(pi(sigma^2)),type="l",xlim=c(0,xmax),...)
 }
 
 .priorSigmaPC <- function(u,alpha,xmax){
@@ -74,33 +74,33 @@
   plot(x,y,xlab=expression(sigma^2),ylab=expression(pi(sigma^2)),type="l",xlim=c(0,xmax))
 }
 
-.priorTableSigma = function(xmax,mrv){
-  x = mrv$priorfile$x
-  if(any(x<=0)){
-    var1dialog <-gtkMessageDialog(mrv$main_window,"destroy-with-parent","warning","ok",
-                                    "Please check the input prior, variance should be in [0, infinity]!")
-    if (var1dialog$run()==GtkResponseType["ok"]){
-      stop("")
-    }
-    var1dialog$destroy()
-  }
-  y = mrv$priorfile$y
-  plot(x,y,xlab=expression(sigma^2),ylab=expression(pi(sigma^2)),type="l",xlim=c(0,xmax))
-}
-
-.priorTableRho = function(xmax,mrv){
-  x = mrv$priorfile$x
-  if(any(x< -1 | x>1)){
-    rhodialog <-gtkMessageDialog(mrv$main_window,"destroy-with-parent","warning","ok",
-                                  "Please check the input prior, correlation should be in [-1, 1]!")
-    if (rhodialog$run()==GtkResponseType["ok"]){
-      stop("")
-    }
-    rhodialog$destroy()
-  }
-  y = mrv$priorfile$y
-  plot(x,y,xlab=expression(rho),ylab=expression(pi(rho)),type="l",xlim=c(-1,xmax))
-}
+# .priorTableSigma = function(xmax,mrv){
+#   x = mrv$priorfile$x
+#   if(any(x<=0)){
+#     var1dialog <-gtkMessageDialog(mrv$main_window,"destroy-with-parent","warning","ok",
+#                                     "Please check the input prior, variance should be in [0, infinity]!")
+#     if (var1dialog$run()==GtkResponseType["ok"]){
+#       stop("")
+#     }
+#     var1dialog$destroy()
+#   }
+#   y = mrv$priorfile$y
+#   plot(x,y,xlab=expression(sigma^2),ylab=expression(pi(sigma^2)),type="l",xlim=c(0,xmax))
+# }
+# 
+# .priorTableRho = function(xmax,mrv){
+#   x = mrv$priorfile$x
+#   if(any(x< -1 | x>1)){
+#     rhodialog <-gtkMessageDialog(mrv$main_window,"destroy-with-parent","warning","ok",
+#                                   "Please check the input prior, correlation should be in [-1, 1]!")
+#     if (rhodialog$run()==GtkResponseType["ok"]){
+#       stop("")
+#     }
+#     rhodialog$destroy()
+#   }
+#   y = mrv$priorfile$y
+#   plot(x,y,xlab=expression(rho),ylab=expression(pi(rho)),type="l",xlim=c(-1,xmax))
+# }
 
 .priorInvWishart = function(nu,R11,R22,R12,xmax){
   R = matrix(c(R11,R12,R12,R22),2,2)
@@ -220,16 +220,16 @@
   plot(drho$x,drho$y,xlab=expression(rho),ylab=expression(pi(rho)),type="l",ylim=c(0,drho$y[10000]+0.65))
 }
 
-.checkNumEntry <- function(entry){
-  text <- entry$getText()
-  if (nzchar(gsub("[0-9.-]", "", text))) {
-    entry$setIconFromStock("primary", "gtk-no")
-    entry$setIconTooltipText("primary","Only numbers are allowed")
-  } else { 
-    entry$setIconFromStock("primary", NULL)
-    entry$setIconTooltipText("secondary", NULL)
-  }
-}
+# .checkNumEntry <- function(entry){
+#   text <- entry$getText()
+#   if (nzchar(gsub("[0-9.-]", "", text))) {
+#     entry$setIconFromStock("primary", "gtk-no")
+#     entry$setIconTooltipText("primary","Only numbers are allowed")
+#   } else { 
+#     entry$setIconFromStock("primary", NULL)
+#     entry$setIconTooltipText("secondary", NULL)
+#   }
+# }
 
 # #########################
 # .makeResult <- function(x){
@@ -973,3 +973,45 @@
   
 }               
 
+
+.hsl_to_rgb <- function(h, s, l) {
+  h <- h / 360
+  r <- g <- b <- 0.0
+  if (s == 0) {
+    r <- g <- b <- l
+  } else {
+    hue_to_rgb <- function(p, q, t) {
+      if (t < 0) { t <- t + 1.0 }
+      if (t > 1) { t <- t - 1.0 }
+      if (t < 1/6) { return(p + (q - p) * 6.0 * t) }
+      if (t < 1/2) { return(q) }
+      if (t < 2/3) { return(p + ((q - p) * ((2/3) - t) * 6)) }
+      return(p)
+    }
+    q <- ifelse(l < 0.5, l * (1.0 + s), l + s - (l*s))
+    p <- 2.0 * l - q
+    r <- hue_to_rgb(p, q, h + 1/3)
+    g <- hue_to_rgb(p, q, h)
+    b <- hue_to_rgb(p, q, h - 1/3)
+  }
+  return(rgb(r,g,b, maxColorValue = 255))
+}
+
+# r, g, b = 0.0 - 1 (0 - 100%)
+# returns h/s/l in a vector, h = 0-360 deg, s = 0.0 - 1 (0-100%), l = 0.0 - 1 (0-100%)
+.rgb_to_hsl <- function(r, g, b) {
+  val_max <- max(c(r, g, b))
+  val_min <- min(c(r, g, b))
+  h <- s <- l <- (val_max + val_min) / 2
+  if (val_max == val_min){
+    h <- s <- 0
+  } else {
+    d <- val_max - val_min
+    s <- ifelse(l > 0.5, d / (2 - val_max - val_min), d / (val_max + val_min))
+    if (val_max == r) { h <- (g - b) / d + (ifelse(g < b, 6, 0)) }
+    if (val_max == g) { h <- (b - r) / d/ + 2 }
+    if (val_max == b) { h <- (r - g) / d + 4 }
+    h <- (h / 6) * 360
+  }
+  return(c(h=h, s=s, l=l))
+}
